@@ -6,8 +6,8 @@ from typing import Union
 
 from openstef.enums import MLModelType
 from openstef.model.objective import (
-    LinearRegressorObjective,
     LGBRegressorObjective,
+    LinearRegressorObjective,
     ProLoafRegressorObjective,
     RegressorObjective,
     XGBQuantileRegressorObjective,
@@ -51,7 +51,7 @@ class ObjectiveCreator:
             raise NotImplementedError(
                 f"No objective for '{model_type}', "
                 f"valid model_types are: {valid_types}"
-                f"or import a custom model"
+                "or import a custom model"
             ) from e
 
         return objective
